@@ -7,7 +7,7 @@ import yaml
 
 from .db import DB
 
-__version__ = "0.5.5"
+__version__ = "1.1.0"
 
 logging.basicConfig(format="%(asctime)s: %(message)s",
                     level=logging.INFO)
@@ -21,6 +21,9 @@ _CONFIG = {
     "download_media": False,
     "media_dir": "media",
     "media_mime_types": [],
+    "proxy": {
+        "enable": False,
+    },
     "fetch_batch_size": 2000,
     "fetch_wait": 5,
     "fetch_limit": 0,
@@ -34,6 +37,7 @@ _CONFIG = {
     "telegram_url": "https://t.me/{id}",
     "per_page": 1000,
     "show_sender_fullname": False,
+    "timezone": "",
     "site_name": "@{group} (Telegram) archive",
     "site_description": "Public archive of @{group} Telegram messages.",
     "meta_description": "@{group} {date} Telegram message archive.",
@@ -109,6 +113,14 @@ def main():
             raise
 
         logging.info("created directory '{}'".format(args.path))
+        
+        # make sure the files are writable
+        os.chmod(args.path, 0o755)
+        for root, dirs, files in os.walk(args.path):
+            for d in dirs:
+                os.chmod(os.path.join(root, d), 0o755)
+            for f in files:
+                os.chmod(os.path.join(root, f), 0o644)
 
     # Sync from Telegram.
     elif args.sync:
@@ -142,7 +154,7 @@ def main():
 
         logging.info("building site")
         config = get_config(args.config)
-        b = Build(config, DB(args.data), args.symlink)
+        b = Build(config, DB(args.data, config["timezone"]), args.symlink)
         b.load_template(args.template)
         if args.rss_template:
             b.load_rss_template(args.rss_template)
